@@ -3,6 +3,7 @@ import requests
 from requests.auth import HTTPDigestAuth
 import json
 import getpass
+import traceback
 from OntimDevTool import auth_server
 from OntimDevTool import secure_access
 
@@ -14,7 +15,7 @@ def get_cpu_id():
 def auth_start():
     # step 1, get nonce by run 'fastboot oem f_auth_start'
     ret = subprocess.run(['fastboot', 'oem', 'f_auth_start'], capture_output=True)
-    nonce = ret.stderr.decode('ascii').split('\n')[3].split('(bootloader) ')[1]
+    nonce = ret.stderr.decode('ascii').split('\n')[5].split('(bootloader) ')[1]
     print(f"Success to get nonce from the phone: {nonce} \n")
     return nonce
 
@@ -27,8 +28,11 @@ def sign(nonce):
     header = {"Content-Type": "application/json"}
 
     if (secure_access):
-        username = input("Please input username: ")
-        password = getpass.getpass("Please input password: ")
+        username = input("Please input username, empty for default user: ")
+        password = getpass.getpass("Please input password, empty for default password: ")
+        if not username:
+            username = "admin"
+            password = "123456"
         auth = HTTPDigestAuth(username, password)
         ret = requests.get(auth_server + "Token/", auth = auth)
         token = json.loads(ret.content.decode('ascii'))['token']
@@ -36,8 +40,12 @@ def sign(nonce):
 
     payload = {"project": "sunfire", "cpuid": cpuid, "nonce": nonce}
     ret = requests.post(auth_server + "AuthDownload/", headers = header, data = json.dumps(payload))
-    auth_resp = json.loads(ret.content.decode('ascii'))['nonce']
-    print(f"Success to get the signature: {auth_resp} \n")
+    try:
+        auth_resp = json.loads(ret.content.decode('ascii'))['nonce']
+        print(f"Success to get the signature: {auth_resp} \n")
+    except Exception as ex:
+        print(f"Failed to get the signature!!! Auth Server returns:\n{ret.content}")
+        print(traceback.print_exc())
     return auth_resp
 
 def step3(auth_resp):
@@ -52,5 +60,11 @@ def authorise():
     signed_data = sign(nonce)    # step 2, get auth response from auth server
     step3(signed_data)           # step 3, send auth response to phone to verify, by run 'fastboot oem permission factory xxxxxx
 
-if __name__ == "__main__":
+def edl():
     authorise()
+    ret = subprocess.run(['fastboot', 'oem', 'edl'], capture_output=True)
+    print(f"edl result: \n {ret.stderr.decode('ascii')}")
+    return ret
+
+if __name__ == "__main__":
+    edl()
