@@ -2,12 +2,13 @@ from pyfiglet import Figlet
 import argparse
 from OntimDevTool import version
 from OntimDevTool.diag_port_controller import open_diag_port, close_diag_port
-from OntimDevTool.auth_controller import authorise
+from OntimDevTool.auth_controller import authorise, edl
 
-FUNCTIONLIST = ["open_diag", "close_diag", "authorise"]
+FUNCTIONLIST = ["open_diag", "close_diag", "authorise", "edl"]
 
 def print_logo():
     logo = Figlet().renderText(f"Ontim Tool      {version}")
+    # logo = f"Ontim Tool      {version}"
     print(logo)
 
 def main():
@@ -68,6 +69,8 @@ def function_hub(project, function):
         close_diag_port()
     elif function == FUNCTIONLIST[2]:
         authorise()
+    elif function == FUNCTIONLIST[3]:
+        edl()
     else:
         print(f"unsupport function: {function}")
 
